@@ -44,6 +44,15 @@ checks that:
 
 =item That the files mention in the "provides" section are present.
 
+=item That the authors field is used instead of author
+
+=item That the name attribute doesn't have a hyphen rather than '::'
+
+=item That if the META6 file specifies a meta6 version greater than 0 that the version strings do not contain a 'v' prefix
+
+The C<meta-ok> takes one optional adverb C<:relaxed-name> that can stop
+the name check being a fail if it is intended to be like that.
+
 There are mechanisms (used internally for testing,) to over-ride the
 location or name of the META file and these can be seen in the test-suite,
 though they won't typically be needed.
@@ -51,14 +60,14 @@ though they won't typically be needed.
 =end pod
 
 
-module Test::META:ver<0.0.2>:auth<github:jonathanstowe> {
+module Test::META:ver<0.0.3>:auth<github:jonathanstowe> {
 
     use Test;
-    use META6:ver(v0.0.3..*);
+    use META6:ver(v0.0.4..*);
 
     our $TESTING = False;
 
-    sub meta-ok() is export(:DEFAULT) {
+    sub meta-ok(:$relaxed-name) is export(:DEFAULT) {
         subtest {
 
             my $meta-file = get-meta();
@@ -66,11 +75,24 @@ module Test::META:ver<0.0.2>:auth<github:jonathanstowe> {
             if $meta-file.defined and $meta-file.e {
                 pass "have a META file";
                 my $meta;
-                lives-ok { $meta = META6.new(file => $meta-file) }, "META parses okay";
+                my Int $seen-vee = 0;
+                lives-ok { 
+                    CONTROL {
+                        when CX::Warn {
+                            if $_.message ~~ /'prefix "v" seen in version string'/ {
+                                $seen-vee++;
+                                $_.resume;
+                            }
+                        }
+                    };
+                    $meta = META6.new(file => $meta-file);
+                }, "META parses okay";
                 if $meta.defined {
                     ok check-mandatory($meta), "have all required entries";
                     ok check-provides($meta), "'provides' looks sane";
                     ok check-authors($meta), "Optional 'authors' and not 'author'";
+                    ok check-name($meta, :$relaxed-name), "name has a hypen rather than '::' (if this is intentional please pass :relaxed-name to meta-ok)";
+                    ok $meta.meta6 eq Version.new(0) ?? True !! $seen-vee == 0, "no 'v' in version strings (meta6 version greater than 0)";
                 }
             }
             else {
@@ -140,6 +162,27 @@ module Test::META:ver<0.0.2>:auth<github:jonathanstowe> {
         $rc;
     }
 
+    our sub check-name(META6:D $meta, :$relaxed-name ) {
+        my Bool $rc = True;
+
+        if $meta.name.defined {
+            if not $relaxed-name {
+                 my Str $name = $meta.name;
+                 if so $name ~~ /\-/ && $name !~~ /\:\:/ {
+                     $rc = False;
+                 }
+            }
+            else {
+                $rc = True;
+            }
+        }
+        else {
+            $rc = False;
+        }
+
+        $rc;
+    }
+
     sub meta-candidates() {
         @*META-CANDIDATES // <META6.json META.info>;
     }
